/* ###################################################################
**     Filename  : calango.h
**     Processor : Calango Analog Die
**     Date/Time : 19.08.2008
**     Abstract  : This header implements the mapping of Calanog Registers.
**
** ###################################################################
*/

#ifndef _CALANGO_H
#define _CALANGO_H

#define  IOBYTE(address)     (*((volatile unsigned char*) (address)))
#define  IOWORD(address)     (*((volatile unsigned int*) (address)))

#define REG_BASE_B  0x0200                /* Base address for the I/O register block */
#define REG_BASE_NB 0x0300                /* Base address for the I/O register block */

/**************** IFR FLASH TRIMMING CONTENT *************************/

#define TRIM0       IOBYTE(0x4C)
#define TRIM1       IOBYTE(0x4D)
#define TRIM2       IOBYTE(0x4E)
#define TRIM3       IOBYTE(0x4F)

/**************** registers I/O map - blocking access ****************/

#define bISRhi      IOBYTE(REG_BASE_B+0x00) // Interrupt Source Register hi
#define bISRlo      IOBYTE(REG_BASE_B+0x01) // Interrupt Source Register lo
#define bISR        IOWORD(REG_BASE_B+0x00) // Interrupt Source Register

#define bIVR        IOBYTE(REG_BASE_B+0x02) // Interrupt Vector Register

#define bVCR        IOBYTE(REG_BASE_B+0x04) // Voltage Control Register
#define bVSR        IOBYTE(REG_BASE_B+0x05) // Voltage Status Register

#define bLXR        IOBYTE(REG_BASE_B+0x08) // Lx Status Register
#define bLXCR       IOBYTE(REG_BASE_B+0x09) // Lx Control Register

#define bWDR        IOBYTE(REG_BASE_B+0x10) // Watchdog Register
#define bWDSR       IOBYTE(REG_BASE_B+0x11) // Watchdog Service Register
#define bWCR        IOBYTE(REG_BASE_B+0x12) // Wake Up Control Register
#define bTCR        IOBYTE(REG_BASE_B+0x13) // Timing Control Register
#define bWSR        IOBYTE(REG_BASE_B+0x14) // Wake Up Source Register
#define bRSR        IOBYTE(REG_BASE_B+0x15) // Reset Status Register
#define bMCR        IOBYTE(REG_BASE_B+0x16) // Mode Control Register

#define bLINR       IOBYTE(REG_BASE_B+0x18) // LIN Register

#define bPTBC1      IOBYTE(REG_BASE_B+0x20) // Port B Configuration Register 1
#define bPTBC2      IOBYTE(REG_BASE_B+0x21) // Port B Configuration Register 2
#define bPTB        IOBYTE(REG_BASE_B+0x22) // Port B Data Register

#define bHSCR       IOBYTE(REG_BASE_B+0x28) // High Side Control Register
#define bHSSR       IOBYTE(REG_BASE_B+0x29) // High Side Status Register

#define bLSCR       IOBYTE(REG_BASE_B+0x30) // Low Side Control Register
#define bLSSR       IOBYTE(REG_BASE_B+0x31) // Low Side Status Register
#define bLSCEN      IOBYTE(REG_BASE_B+0x32) // Low-Side Control Enable Register
        
#define bHSR        IOBYTE(REG_BASE_B+0x38) // Hall Supply Register

#define bCSR        IOBYTE(REG_BASE_B+0x3C) // Current Sense Register
            
#define bSCIBDhi    IOBYTE(REG_BASE_B+0x40) // SCI Baud Rate Register hi
#define bSCIBDlo    IOBYTE(REG_BASE_B+0x41) // SCI Baud Rate Register lo
#define bSCIBD      IOWORD(REG_BASE_B+0x40) // SCI Baud Rate Register
#define bSCIC1      IOBYTE(REG_BASE_B+0x42) // SCI Control Register 1
#define bSCIC2      IOBYTE(REG_BASE_B+0x43) // SCI Control Register 2
#define bSCIS1      IOBYTE(REG_BASE_B+0x44) // SCI Status Register 1
#define bSCIS2      IOBYTE(REG_BASE_B+0x45) // SCI Status Register 2
#define bSCIC3      IOBYTE(REG_BASE_B+0x46) // SCI Control Register 3
#define bSCID       IOBYTE(REG_BASE_B+0x47) // SCI Data Register 

#define bPWMCTL     IOBYTE(REG_BASE_B+0x60) // PWM Control Register
#define bPWMPRCLK   IOBYTE(REG_BASE_B+0x61) // PWM Prescale Clock Select Register
#define bPWMSCLA    IOBYTE(REG_BASE_B+0x62) // PWM Scale A Register
#define bPWMSCLB    IOBYTE(REG_BASE_B+0x63) // PWM Scale B Register
#define bPWMCNT0    IOBYTE(REG_BASE_B+0x64) // PWM Channel Counter Register 0
#define bPWMCNT1    IOBYTE(REG_BASE_B+0x65) // PWM Channel Counter Register 1
#define bPWMPER0    IOBYTE(REG_BASE_B+0x66) // PWM Channel Period Register 0
#define bPWMPER1    IOBYTE(REG_BASE_B+0x67) // PWM Channel Period Register 1
#define bPWMDTY0    IOBYTE(REG_BASE_B+0x68) // PWM Channel Duty Register 0
#define bPWMDTY1    IOBYTE(REG_BASE_B+0x69) // PWM Channel Duty Register 1

#define bACR	      IOBYTE(REG_BASE_B+0x80) // ADC Config Register
#define bASR	      IOBYTE(REG_BASE_B+0x81) // ADC Status Register
#define bACCRhi	    IOBYTE(REG_BASE_B+0x82) // ADC Conversion Control Register hi 
#define bACCRlo	    IOBYTE(REG_BASE_B+0x83) // ADC Conversion Control Register lo
#define bACCR 	    IOWORD(REG_BASE_B+0x82) // ADC Conversion Control Register
#define bACCSRhi	  IOBYTE(REG_BASE_B+0x84) // ADC Conversion Complete Register hi
#define bACCSRlo	  IOBYTE(REG_BASE_B+0x85) // ADC Conversion Complete Register lo
#define bACCSR	    IOWORD(REG_BASE_B+0x84) // ADC Conversion Complete Register
#define bADR0hi	    IOBYTE(REG_BASE_B+0x86) // ADC Data Result Register 0 hi
#define bADR0lo	    IOBYTE(REG_BASE_B+0x87) // ADC Data Result Register 0 lo
#define bADR0 	    IOWORD(REG_BASE_B+0x86) // ADC Data Result Register 0
#define bADR1hi	    IOBYTE(REG_BASE_B+0x88) // ADC Data Result Register 1 hi
#define bADR1lo	    IOBYTE(REG_BASE_B+0x89) // ADC Data Result Register 1 lo
#define bADR1 	    IOWORD(REG_BASE_B+0x88) // ADC Data Result Register 1
#define bADR2hi	    IOBYTE(REG_BASE_B+0x8A) // ADC Data Result Register 2 hi
#define bADR2lo	    IOBYTE(REG_BASE_B+0x8B) // ADC Data Result Register 2 lo
#define bADR2 	    IOWORD(REG_BASE_B+0x8A) // ADC Data Result Register 2
#define bADR3hi	    IOBYTE(REG_BASE_B+0x8C) // ADC Data Result Register 3 hi
#define bADR3lo	    IOBYTE(REG_BASE_B+0x8D) // ADC Data Result Register 3 lo
#define bADR3 	    IOWORD(REG_BASE_B+0x8C) // ADC Data Result Register 3
#define bADR4hi	    IOBYTE(REG_BASE_B+0x8E) // ADC Data Result Register 4 hi
#define bADR4lo	    IOBYTE(REG_BASE_B+0x8F) // ADC Data Result Register 4 lo
#define bADR4 	    IOWORD(REG_BASE_B+0x8E) // ADC Data Result Register 4
#define bADR5hi	    IOBYTE(REG_BASE_B+0x90) // ADC Data Result Register 5 hi
#define bADR5lo	    IOBYTE(REG_BASE_B+0x91) // ADC Data Result Register 5 lo
#define bADR5	      IOWORD(REG_BASE_B+0x90) // ADC Data Result Register 5
#define bADR6hi	    IOBYTE(REG_BASE_B+0x92) // ADC Data Result Register 6 hi
#define bADR6lo	    IOBYTE(REG_BASE_B+0x93) // ADC Data Result Register 6 lo
#define bADR6 	    IOWORD(REG_BASE_B+0x92) // ADC Data Result Register 6
#define bADR7hi	    IOBYTE(REG_BASE_B+0x94) // ADC Data Result Register 7 hi
#define bADR7lo	    IOBYTE(REG_BASE_B+0x95) // ADC Data Result Register 7 lo
#define bADR7 	    IOWORD(REG_BASE_B+0x94) // ADC Data Result Register 7
#define bADR8hi	    IOBYTE(REG_BASE_B+0x96) // ADC Data Result Register 8 hi
#define bADR8lo	    IOBYTE(REG_BASE_B+0x97) // ADC Data Result Register 8 lo
#define bADR8 	    IOWORD(REG_BASE_B+0x96) // ADC Data Result Register 8
#define bADR9hi	    IOBYTE(REG_BASE_B+0x98) // ADC Data Result Register 9 hi
#define bADR9lo	    IOBYTE(REG_BASE_B+0x99) // ADC Data Result Register 9 lo
#define bADR9 	    IOWORD(REG_BASE_B+0x98) // ADC Data Result Register 9
#define bADR10hi	  IOBYTE(REG_BASE_B+0x9A) // ADC Data Result Register 10 hi
#define bADR10lo	  IOBYTE(REG_BASE_B+0x9B) // ADC Data Result Register 10 lo
#define bADR10 	    IOWORD(REG_BASE_B+0x9A) // ADC Data Result Register 10
#define bADR11hi	  IOBYTE(REG_BASE_B+0x9C) // ADC Data Result Register 11 hi
#define bADR11lo	  IOBYTE(REG_BASE_B+0x9D) // ADC Data Result Register 11 lo
#define bADR11      IOWORD(REG_BASE_B+0x9C) // ADC Data Result Register 11
#define bADR12hi	  IOBYTE(REG_BASE_B+0x9E) // ADC Data Result Register 12 hi
#define bADR12lo	  IOBYTE(REG_BASE_B+0x9F) // ADC Data Result Register 12 lo
#define bADR12      IOWORD(REG_BASE_B+0x9E) // ADC Data Result Register 12
#define bADR14hi	  IOBYTE(REG_BASE_B+0xA2) // ADC Data Result Register 14 hi
#define bADR14lo	  IOBYTE(REG_BASE_B+0xA3) // ADC Data Result Register 14 lo
#define bADR14      IOWORD(REG_BASE_B+0xA2) // ADC Data Result Register 14
#define bADR15hi	  IOBYTE(REG_BASE_B+0xA4) // ADC Data Result Register 15 hi
#define bADR15lo	  IOBYTE(REG_BASE_B+0xA5) // ADC Data Result Register 15 lo
#define bADR15	    IOWORD(REG_BASE_B+0xA4) // ADC Data Result Register 15

#define bTIOS	      IOBYTE(REG_BASE_B+0xC0) // Timer Input Capture/Output Compare Select
#define bCFORC	    IOBYTE(REG_BASE_B+0xC1) // Timer Compare Force Register
#define bOC3M	      IOBYTE(REG_BASE_B+0xC2) // Output Compare 3 Mask Register
#define bOC3D	      IOBYTE(REG_BASE_B+0xC3) // Output Compare 3 Data Register
#define bTCNThi	    IOBYTE(REG_BASE_B+0xC4) // Timer Count Register hi
#define bTCNTlo	    IOBYTE(REG_BASE_B+0xC5) // Timer Count Register lo
#define bTCNT 	    IOWORD(REG_BASE_B+0xC4) // Timer Count Register
#define bTSCR1	    IOBYTE(REG_BASE_B+0xC6) // Timer System Control Register 1
#define bTTOV	      IOBYTE(REG_BASE_B+0xC7) // Timer Toggle Overflow Register
#define bTCTL1	    IOBYTE(REG_BASE_B+0xC8) // Timer Control Register 1
#define bTCTL2	    IOBYTE(REG_BASE_B+0xC9) // Timer Control Register 2
#define bTIE	      IOBYTE(REG_BASE_B+0xCA) // Timer Interrupt Enable Register
#define bTSCR2	    IOBYTE(REG_BASE_B+0xCB) // Timer System Control Register 2
#define bTFLG1	    IOBYTE(REG_BASE_B+0xCC) // Main Timer Interrupt Flag 1
#define bTFLG2	    IOBYTE(REG_BASE_B+0xCD) // Main Timer Interrupt Flag 2
#define bTC0hi	    IOBYTE(REG_BASE_B+0xCE) // Timer Input Capture/Output Compare Register 0 hi
#define bTC0lo	    IOBYTE(REG_BASE_B+0xCF) // Timer Input Capture/Output Compare Register 0 lo
#define bTC0 	      IOWORD(REG_BASE_B+0xCE) // Timer Input Capture/Output Compare Register 0 
#define bTC1hi	    IOBYTE(REG_BASE_B+0xD0) // Timer Input Capture/Output Compare Register 1 hi
#define bTC1lo	    IOBYTE(REG_BASE_B+0xD1) // Timer Input Capture/Output Compare Register 1 lo
#define bTC1 	      IOWORD(REG_BASE_B+0xD0) // Timer Input Capture/Output Compare Register 1
#define bTC2hi	    IOBYTE(REG_BASE_B+0xD2) // Timer Input Capture/Output Compare Register 2 hi
#define bTC2lo	    IOBYTE(REG_BASE_B+0xD3) // Timer Input Capture/Output Compare Register 2 lo
#define bTC2 	      IOWORD(REG_BASE_B+0xD2) // Timer Input Capture/Output Compare Register 2
#define bTC3hi	    IOBYTE(REG_BASE_B+0xD4) // Timer Input Capture/Output Compare Register 3 hi
#define bTC3lo	    IOBYTE(REG_BASE_B+0xD5) // Timer Input Capture/Output Compare Register 3 lo
#define bTC3        IOWORD(REG_BASE_B+0xD4) // Timer Input Capture/Output Compare Register 3

#define bCTR0	      IOBYTE(REG_BASE_B+0xF0) //	Calango Trimming Register 0
#define bCTR1	      IOBYTE(REG_BASE_B+0xF1) //	Calango Trimming Register 1
#define bCTR2	      IOBYTE(REG_BASE_B+0xF2) //	Calango Trimming Register 2
#define bCTR3	      IOBYTE(REG_BASE_B+0xF3) //	Calango Trimming Register 3

#define bSRR        IOBYTE(REG_BASE_B+0xF4) //	Silicon Revision Register

/**************** registers I/O map - non blocking access ************/

#define nbISRhi     IOBYTE(REG_BASE_NB+0x00)


#define nbISRhi     IOBYTE(REG_BASE_NB+0x00) // Interrupt Source Register hi
#define nbISRlo     IOBYTE(REG_BASE_NB+0x01) // Interrupt Source Register lo
#define nbISR       IOWORD(REG_BASE_NB+0x00) // Interrupt Source Register

#define nbIVR       IOBYTE(REG_BASE_NB+0x02) // Interrupt Vector Register

#define nbVCR       IOBYTE(REG_BASE_NB+0x04) // Voltage Control Register
#define nbVSR       IOBYTE(REG_BASE_NB+0x05) // Voltage Status Register

#define nbLXR       IOBYTE(REG_BASE_NB+0x08) // Lx Status Register
#define nbLXCR      IOBYTE(REG_BASE_NB+0x09) // Lx Control Register

#define nbWDR       IOBYTE(REG_BASE_NB+0x10) // Watchdog Register
#define nbWDSR      IOBYTE(REG_BASE_NB+0x11) // Watchdog Service Register
#define nbWCR       IOBYTE(REG_BASE_NB+0x12) // Wake Up Control Register
#define nbTCR       IOBYTE(REG_BASE_NB+0x13) // Timing Control Register
#define nbWSR       IOBYTE(REG_BASE_NB+0x14) // Wake Up Source Register
#define nbRSR       IOBYTE(REG_BASE_NB+0x15) // Reset Status Register
#define nbMCR       IOBYTE(REG_BASE_NB+0x16) // Mode Control Register

#define nbLINR      IOBYTE(REG_BASE_NB+0x18) // LIN Register

#define nbPTBC1     IOBYTE(REG_BASE_NB+0x20) // Port B Configuration Register 1
#define nbPTBC2     IOBYTE(REG_BASE_NB+0x21) // Port B Configuration Register 2
#define nbPTB       IOBYTE(REG_BASE_NB+0x22) // Port B Data Register

#define nbHSCR      IOBYTE(REG_BASE_NB+0x28) // High Side Control Register
#define nbHSSR      IOBYTE(REG_BASE_NB+0x29) // High Side Status Register

#define nbLSCR      IOBYTE(REG_BASE_NB+0x30) // Low Side Control Register
#define nbLSSR      IOBYTE(REG_BASE_NB+0x31) // Low Side Status Register
#define nbLSCEN     IOBYTE(REG_BASE_NB+0x32) // Low-Side Control Enable Register

#define nbHSR       IOBYTE(REG_BASE_NB+0x38) // Hall Supply Register

#define nbCSR       IOBYTE(REG_BASE_NB+0x3C) // Current Sense Register
            
#define nbSCIBDhi   IOBYTE(REG_BASE_NB+0x40) // SCI Baud Rate Register hi
#define nbSCIBDlo   IOBYTE(REG_BASE_NB+0x41) // SCI Baud Rate Register lo
#define nbSCIBD     IOWORD(REG_BASE_NB+0x40) // SCI Baud Rate Register
#define nbSCIC1     IOBYTE(REG_BASE_NB+0x42) // SCI Control Register 1
#define nbSCIC2     IOBYTE(REG_BASE_NB+0x43) // SCI Control Register 2
#define nbSCIS1     IOBYTE(REG_BASE_NB+0x44) // SCI Status Register 1
#define nbSCIS2     IOBYTE(REG_BASE_NB+0x45) // SCI Status Register 2
#define nbSCIC3     IOBYTE(REG_BASE_NB+0x46) // SCI Control Register 3
#define nbSCID      IOBYTE(REG_BASE_NB+0x47) // SCI Data Register 

#define nbPWMCTL    IOBYTE(REG_BASE_NB+0x60) // PWM Control Register
#define nbPWMPRCLK  IOBYTE(REG_BASE_NB+0x61) // PWM Prescale Clock Select Register
#define nbPWMSCLA   IOBYTE(REG_BASE_NB+0x62) // PWM Scale A Register
#define nbPWMSCLB   IOBYTE(REG_BASE_NB+0x63) // PWM Scale B Register
#define nbPWMCNT0   IOBYTE(REG_BASE_NB+0x64) // PWM Channel Counter Register 0
#define nbPWMCNT1   IOBYTE(REG_BASE_NB+0x65) // PWM Channel Counter Register 1
#define nbPWMPER0   IOBYTE(REG_BASE_NB+0x66) // PWM Channel Period Register 0
#define nbPWMPER1   IOBYTE(REG_BASE_NB+0x67) // PWM Channel Period Register 1
#define nbPWMDTY0   IOBYTE(REG_BASE_NB+0x68) // PWM Channel Duty Register 0
#define nbPWMDTY1   IOBYTE(REG_BASE_NB+0x69) // PWM Channel Duty Register 1

#define nbACR	      IOBYTE(REG_BASE_NB+0x80) // ADC Config Register
#define nbASR	      IOBYTE(REG_BASE_NB+0x81) // ADC Status Register
#define nbACCRhi	  IOBYTE(REG_BASE_NB+0x82) // ADC Conversion Control Register hi 
#define nbACCRlo	  IOBYTE(REG_BASE_NB+0x83) // ADC Conversion Control Register lo
#define nbACCR 	    IOWORD(REG_BASE_NB+0x82) // ADC Conversion Control Register
#define nbACCSRhi	  IOBYTE(REG_BASE_NB+0x84) // ADC Conversion Complete Register hi
#define nbACCSRlo	  IOBYTE(REG_BASE_NB+0x85) // ADC Conversion Complete Register lo
#define nbACCSR	    IOWORD(REG_BASE_NB+0x84) // ADC Conversion Complete Register
#define nbADR0hi	  IOBYTE(REG_BASE_NB+0x86) // ADC Data Result Register 0 hi
#define nbADR0lo	  IOBYTE(REG_BASE_NB+0x87) // ADC Data Result Register 0 lo
#define nbADR0 	    IOWORD(REG_BASE_NB+0x86) // ADC Data Result Register 0
#define nbADR1hi	  IOBYTE(REG_BASE_NB+0x88) // ADC Data Result Register 1 hi
#define nbADR1lo	  IOBYTE(REG_BASE_NB+0x89) // ADC Data Result Register 1 lo
#define nbADR1 	    IOWORD(REG_BASE_NB+0x88) // ADC Data Result Register 1
#define nbADR2hi	  IOBYTE(REG_BASE_NB+0x8A) // ADC Data Result Register 2 hi
#define nbADR2lo	  IOBYTE(REG_BASE_NB+0x8B) // ADC Data Result Register 2 lo
#define nbADR2 	    IOWORD(REG_BASE_NB+0x8A) // ADC Data Result Register 2
#define nbADR3hi	  IOBYTE(REG_BASE_NB+0x8C) // ADC Data Result Register 3 hi
#define nbADR3lo	  IOBYTE(REG_BASE_NB+0x8D) // ADC Data Result Register 3 lo
#define nbADR3 	    IOWORD(REG_BASE_NB+0x8C) // ADC Data Result Register 3
#define nbADR4hi	  IOBYTE(REG_BASE_NB+0x8E) // ADC Data Result Register 4 hi
#define nbADR4lo	  IOBYTE(REG_BASE_NB+0x8F) // ADC Data Result Register 4 lo
#define nbADR4 	    IOWORD(REG_BASE_NB+0x8E) // ADC Data Result Register 4
#define nbADR5hi	  IOBYTE(REG_BASE_NB+0x90) // ADC Data Result Register 5 hi
#define nbADR5lo	  IOBYTE(REG_BASE_NB+0x91) // ADC Data Result Register 5 lo
#define nbADR5	    IOWORD(REG_BASE_NB+0x90) // ADC Data Result Register 5
#define nbADR6hi	  IOBYTE(REG_BASE_NB+0x92) // ADC Data Result Register 6 hi
#define nbADR6lo	  IOBYTE(REG_BASE_NB+0x93) // ADC Data Result Register 6 lo
#define nbADR6 	    IOWORD(REG_BASE_NB+0x92) // ADC Data Result Register 6
#define nbADR7hi	  IOBYTE(REG_BASE_NB+0x94) // ADC Data Result Register 7 hi
#define nbADR7lo	  IOBYTE(REG_BASE_NB+0x95) // ADC Data Result Register 7 lo
#define nbADR7 	    IOWORD(REG_BASE_NB+0x94) // ADC Data Result Register 7
#define nbADR8hi	  IOBYTE(REG_BASE_NB+0x96) // ADC Data Result Register 8 hi
#define nbADR8lo	  IOBYTE(REG_BASE_NB+0x97) // ADC Data Result Register 8 lo
#define nbADR8 	    IOWORD(REG_BASE_NB+0x96) // ADC Data Result Register 8
#define nbADR9hi	  IOBYTE(REG_BASE_NB+0x98) // ADC Data Result Register 9 hi
#define nbADR9lo	  IOBYTE(REG_BASE_NB+0x99) // ADC Data Result Register 9 lo
#define nbADR9 	    IOWORD(REG_BASE_NB+0x98) // ADC Data Result Register 9
#define nbADR10hi	  IOBYTE(REG_BASE_NB+0x9A) // ADC Data Result Register 10 hi
#define nbADR10lo	  IOBYTE(REG_BASE_NB+0x9B) // ADC Data Result Register 10 lo
#define nbADR10 	  IOWORD(REG_BASE_NB+0x9A) // ADC Data Result Register 10
#define nbADR11hi	  IOBYTE(REG_BASE_NB+0x9C) // ADC Data Result Register 11 hi
#define nbADR11lo	  IOBYTE(REG_BASE_NB+0x9D) // ADC Data Result Register 11 lo
#define nbADR11     IOWORD(REG_BASE_NB+0x9C) // ADC Data Result Register 11
#define nbADR12hi	  IOBYTE(REG_BASE_NB+0x9E) // ADC Data Result Register 12 hi
#define nbADR12lo	  IOBYTE(REG_BASE_NB+0x9F) // ADC Data Result Register 12 lo
#define nbADR12     IOWORD(REG_BASE_NB+0x9E) // ADC Data Result Register 12
#define nbADR14hi	  IOBYTE(REG_BASE_NB+0xA2) // ADC Data Result Register 14 hi
#define nbADR14lo	  IOBYTE(REG_BASE_NB+0xA3) // ADC Data Result Register 14 lo
#define nbADR14     IOWORD(REG_BASE_NB+0xA2) // ADC Data Result Register 14
#define nbADR15hi	  IOBYTE(REG_BASE_NB+0xA4) // ADC Data Result Register 15 hi
#define nbADR15lo	  IOBYTE(REG_BASE_NB+0xA5) // ADC Data Result Register 15 lo
#define nbADR15	    IOWORD(REG_BASE_NB+0xA4) // ADC Data Result Register 15

#define nbTIOS	    IOBYTE(REG_BASE_NB+0xC0) // Timer Input Capture/Output Compare Select
#define nbCFORC	    IOBYTE(REG_BASE_NB+0xC1) // Timer Compare Force Register
#define nbOC3M	    IOBYTE(REG_BASE_NB+0xC2) // Output Compare 3 Mask Register
#define nbOC3D	    IOBYTE(REG_BASE_NB+0xC3) // Output Compare 3 Data Register
#define nbTCNThi	  IOBYTE(REG_BASE_NB+0xC4) // Timer Count Register hi
#define nbTCNTlo	  IOBYTE(REG_BASE_NB+0xC5) // Timer Count Register lo
#define nbTCNT 	    IOWORD(REG_BASE_NB+0xC4) // Timer Count Register
#define nbTSCR1	    IOBYTE(REG_BASE_NB+0xC6) // Timer System Control Register 1
#define nbTTOV	    IOBYTE(REG_BASE_NB+0xC7) // Timer Toggle Overflow Register
#define nbTCTL1	    IOBYTE(REG_BASE_NB+0xC8) // Timer Control Register 1
#define nbTCTL2	    IOBYTE(REG_BASE_NB+0xC9) // Timer Control Register 2
#define nbTIE	      IOBYTE(REG_BASE_NB+0xCA) // Timer Interrupt Enable Register
#define nbTSCR2	    IOBYTE(REG_BASE_NB+0xCB) // Timer System Control Register 2
#define nbTFLG1	    IOBYTE(REG_BASE_NB+0xCC) // Main Timer Interrupt Flag 1
#define nbTFLG2	    IOBYTE(REG_BASE_NB+0xCD) // Main Timer Interrupt Flag 2
#define nbTC0hi	    IOBYTE(REG_BASE_NB+0xCE) // Timer Input Capture/Output Compare Register 0 hi
#define nbTC0lo	    IOBYTE(REG_BASE_NB+0xCF) // Timer Input Capture/Output Compare Register 0 lo
#define nbTC0 	    IOWORD(REG_BASE_NB+0xCE) // Timer Input Capture/Output Compare Register 0 
#define nbTC1hi	    IOBYTE(REG_BASE_NB+0xD0) // Timer Input Capture/Output Compare Register 1 hi
#define nbTC1lo	    IOBYTE(REG_BASE_NB+0xD1) // Timer Input Capture/Output Compare Register 1 lo
#define nbTC1 	    IOWORD(REG_BASE_NB+0xD0) // Timer Input Capture/Output Compare Register 1
#define nbTC2hi	    IOBYTE(REG_BASE_NB+0xD2) // Timer Input Capture/Output Compare Register 2 hi
#define nbTC2lo	    IOBYTE(REG_BASE_NB+0xD3) // Timer Input Capture/Output Compare Register 2 lo
#define nbTC2 	    IOWORD(REG_BASE_NB+0xD2) // Timer Input Capture/Output Compare Register 2
#define nbTC3hi	    IOBYTE(REG_BASE_NB+0xD4) // Timer Input Capture/Output Compare Register 3 hi
#define nbTC3lo	    IOBYTE(REG_BASE_NB+0xD5) // Timer Input Capture/Output Compare Register 3 lo
#define nbTC3       IOWORD(REG_BASE_NB+0xD4) // Timer Input Capture/Output Compare Register 3

#define nbCTR0	    IOBYTE(REG_BASE_NB+0xF0) //	Calango Trimming Register 0
#define nbCTR1	    IOBYTE(REG_BASE_NB+0xF1) //	Calango Trimming Register 1
#define nbCTR2	    IOBYTE(REG_BASE_NB+0xF2) //	Calango Trimming Register 2
#define nbCTR3	    IOBYTE(REG_BASE_NB+0xF3) //	Calango Trimming Register 3

#define nbSRR       IOBYTE(REG_BASE_NB+0xF4) //	Silicon Revision Register

#endif
